@@ -7,14 +7,31 @@ use warnings;
 use Error::Pure qw(err);
 use Graphics::ColorNames::CSS;
 use List::Util 1.33 qw(none);
+use Mo::utils 0.06 qw(check_array);
 use Readonly;
 
-Readonly::Array our @EXPORT_OK => qw(check_css_class check_css_color check_css_unit);
+Readonly::Array our @EXPORT_OK => qw(check_array_css_color check_css_class check_css_color check_css_unit);
 Readonly::Array our @ABSOLUTE_LENGTHS => qw(cm mm in px pt pc);
 Readonly::Array our @RELATIVE_LENGTHS => qw(em ex ch rem vw vh vmin vmax %);
 Readonly::Array our @COLOR_FUNC => qw(rgb rgba hsl hsla);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
+
+sub check_array_css_color {
+	my ($self, $key) = @_;
+
+	if (! exists $self->{$key}) {
+		return;
+	}
+
+	check_array($self, $key);
+
+	foreach my $css_color (@{$self->{$key}}) {
+		_check_color($css_color, $key);
+	}
+
+	return;
+}
 
 sub check_css_class {
 	my ($self, $key) = @_;
@@ -39,64 +56,7 @@ sub check_css_color {
 
 	_check_key($self, $key) && return;
 
-	my $funcs = join '|', @COLOR_FUNC;
-	if ($self->{$key} =~ m/^#(.*)$/ms) {
-		my $rgb = $1;
-		if (length $rgb == 3 || length $rgb == 6 || length $rgb == 8) {
-			if ($rgb !~ m/^[0-9A-Fa-f]+$/ms) {
-				err "Parameter '$key' has bad rgb color (bad hex number).",
-					'Value', $self->{$key},
-				;
-			}
-		} else {
-			err "Parameter '$key' has bad rgb color (bad length).",
-				'Value', $self->{$key},
-			;
-		}
-	} elsif ($self->{$key} =~ m/^($funcs)\((.*)\)$/ms) {
-		my $func = $1;
-		my $args_string = $2;
-		my @args = split m/\s*,\s*/ms, $args_string;
-		if ($func eq 'rgb') {
-			if (@args != 3) {
-				err "Parameter '$key' has bad rgb color (bad number of arguments).",
-					'Value', $self->{$key},
-				;
-			}
-			_check_colors($self, $key, \@args, $func);
-		} elsif ($func eq 'rgba') {
-			if (@args != 4) {
-				err "Parameter '$key' has bad rgba color (bad number of arguments).",
-					'Value', $self->{$key},
-				;
-			}
-			_check_colors($self, $key, \@args, $func);
-			_check_alpha($self, $key, \@args, $func);
-		} elsif ($func eq 'hsl') {
-			if (@args != 3) {
-				err "Parameter '$key' has bad hsl color (bad number of arguments).",
-					'Value', $self->{$key},
-				;
-			}
-			_check_degree($self, $key, \@args, $func);
-			_check_percent($self, $key, \@args, $func);
-		} else {
-			if (@args != 4) {
-				err "Parameter '$key' has bad hsla color (bad number of arguments).",
-					'Value', $self->{$key},
-				;
-			}
-			_check_degree($self, $key, \@args, $func);
-			_check_percent($self, $key, \@args, $func);
-			_check_alpha($self, $key, \@args, $func);
-		}
-	} else {
-		if (none { $self->{$key} eq $_ } keys %{Graphics::ColorNames::CSS->NamesRgbTable}) {
-			err "Parameter '$key' has bad color name.",
-				'Value', $self->{$key},
-			;
-		}
-	}
+	_check_color($self->{$key}, $key);
 
 	return;
 }
@@ -123,25 +83,90 @@ sub check_css_unit {
 }
 
 sub _check_alpha {
-	my ($self, $key, $args_ar, $func) = @_;
+	my ($value, $key, $args_ar, $func) = @_;
 
 	my $alpha = $args_ar->[3];
 	if ($alpha !~ m/^[\d\.]+$/ms || $alpha > 1) {
 		err "Parameter '$key' has bad $func alpha.",
-			'Value', $self->{$key},
+			'Value', $value,
 		;
 	}
 
 	return;
 }
 
+sub _check_color {
+	my ($value, $key) = @_;
+
+	my $funcs = join '|', @COLOR_FUNC;
+	if ($value =~ m/^#(.*)$/ms) {
+		my $rgb = $1;
+		if (length $rgb == 3 || length $rgb == 6 || length $rgb == 8) {
+			if ($rgb !~ m/^[0-9A-Fa-f]+$/ms) {
+				err "Parameter '$key' has bad rgb color (bad hex number).",
+					'Value', $value,
+				;
+			}
+		} else {
+			err "Parameter '$key' has bad rgb color (bad length).",
+				'Value', $value,
+			;
+		}
+	} elsif ($value =~ m/^($funcs)\((.*)\)$/ms) {
+		my $func = $1;
+		my $args_string = $2;
+		my @args = split m/\s*,\s*/ms, $args_string;
+		if ($func eq 'rgb') {
+			if (@args != 3) {
+				err "Parameter '$key' has bad rgb color (bad number of arguments).",
+					'Value', $value,
+				;
+			}
+			_check_colors($value, $key, \@args, $func);
+		} elsif ($func eq 'rgba') {
+			if (@args != 4) {
+				err "Parameter '$key' has bad rgba color (bad number of arguments).",
+					'Value', $value,
+				;
+			}
+			_check_colors($value, $key, \@args, $func);
+			_check_alpha($value, $key, \@args, $func);
+		} elsif ($func eq 'hsl') {
+			if (@args != 3) {
+				err "Parameter '$key' has bad hsl color (bad number of arguments).",
+					'Value', $value,
+				;
+			}
+			_check_degree($value, $key, \@args, $func);
+			_check_percent($value, $key, \@args, $func);
+		} else {
+			if (@args != 4) {
+				err "Parameter '$key' has bad hsla color (bad number of arguments).",
+					'Value', $value,
+				;
+			}
+			_check_degree($value, $key, \@args, $func);
+			_check_percent($value, $key, \@args, $func);
+			_check_alpha($value, $key, \@args, $func);
+		}
+	} else {
+		if (none { $value eq $_ } keys %{Graphics::ColorNames::CSS->NamesRgbTable}) {
+			err "Parameter '$key' has bad color name.",
+				'Value', $value,
+			;
+		}
+	}
+
+	return;
+}
+
 sub _check_colors {
-	my ($self, $key, $args_ar, $func) = @_;
+	my ($value, $key, $args_ar, $func) = @_;
 
 	foreach my $i (@{$args_ar}[0 .. 2]) {
 		if ($i !~ m/^\d+$/ms || $i > 255) {
 			err "Parameter '$key' has bad $func color (bad number).",
-				'Value', $self->{$key},
+				'Value', $value,
 			;
 		}
 	}
@@ -150,12 +175,12 @@ sub _check_colors {
 }
 
 sub _check_degree {
-	my ($self, $key, $args_ar, $func) = @_;
+	my ($value, $key, $args_ar, $func) = @_;
 
 	my $angle = $args_ar->[0];
 	if ($angle !~ m/^\d+$/ms || $angle > 360) {
 		err "Parameter '$key' has bad $func degree.",
-			'Value', $self->{$key},
+			'Value', $value,
 		;
 	}
 
@@ -173,7 +198,7 @@ sub _check_key {
 }
 
 sub _check_percent {
-	my ($self, $key, $args_ar, $func) = @_;
+	my ($value, $key, $args_ar, $func) = @_;
 
 	foreach my $i (@{$args_ar}[1 .. 2]) {
 
@@ -183,20 +208,20 @@ sub _check_percent {
 			my $p = $2;
 			if (! $p) {
 				err "Parameter '$key' has bad $func percent (missing %).",
-					'Value', $self->{$key},
+					'Value', $value,
 				;
 			}
 		# Check percent number.
 		} else {
 			err "Parameter '$key' has bad $func percent.",
-				'Value', $self->{$key},
+				'Value', $value,
 			;
 		}
 
 		# Check percent value.
 		if ($i > 100) {
 			err "Parameter '$key' has bad $func percent.",
-				'Value', $self->{$key},
+				'Value', $value,
 			;
 		}
 	}
@@ -218,8 +243,9 @@ Mo::utils::CSS - Mo CSS utilities.
 
 =head1 SYNOPSIS
 
- use Mo::utils::CSS qw(check_css_color check_css_unit);
+ use Mo::utils::CSS qw(check_array_css_color check_css_class check_css_color check_css_unit);
 
+ check_array_css_color($self, $key);
  check_css_class($self, $key);
  check_css_color($self, $key);
  check_css_unit($self, $key);
@@ -230,6 +256,17 @@ Mo utilities for checking of CSS style things.
 
 =head1 SUBROUTINES
 
+=head2 C<check_array_css_color>
+
+ check_array_css_color($self, $key);
+
+Check parameter defined by C<$key> which is reference to array.
+Check if all values are CSS colors.
+
+Put error if check isn't ok.
+
+Returns undef.
+
 =head2 C<check_css_class>
 
  check_css_class($self, $key);
@@ -237,6 +274,8 @@ Mo utilities for checking of CSS style things.
 Check parameter defined by C<$key> if it's CSS class name.
 Value could be undefined.
 
+Put error if check isn't ok.
+
 Returns undef.
 
 =head2 C<check_css_color>
@@ -246,6 +285,8 @@ Returns undef.
 Check parameter defined by C<$key> if it's CSS color.
 Value could be undefined.
 
+Put error if check isn't ok.
+
 Returns undef.
 
 =head2 C<check_css_unit>
@@ -255,10 +296,23 @@ Returns undef.
 Check parameter defined by C<$key> if it's CSS unit.
 Value could be undefined.
 
+Put error if check isn't ok.
+
 Returns undef.
 
 =head1 ERRORS
 
+ check_array_css_color():
+         Parameter '%s' has bad color name.
+                 Value: %s
+         Parameter '%s' has bad rgb color (bad hex number).
+                 Value: %s
+         Parameter '%s' has bad rgb color (bad length).
+                 Value: %s
+         Parameter '%s' must be a array.
+                 Value: %s
+                 Reference: %s
+
  check_css_class():
          Parameter '%s' has bad CSS class name.
                  Value: %s
@@ -281,6 +335,54 @@ Returns undef.
 
 =head1 EXAMPLE1
 
+=for comment filename=check_array_css_color_ok.pl
+
+ use strict;
+ use warnings;
+
+ use Mo::utils::CSS qw(check_array_css_color);
+
+ my $self = {
+         'key' => [
+                 'red',
+                 '#F00', '#FF0000', '#FF000000',
+                 'rgb(255,0,0)', 'rgba(255,0,0,0.3)',
+                 'hsl(120, 100%, 50%)', 'hsla(120, 100%, 50%, 0.3)',
+         ],
+ };
+ check_array_css_color($self, 'key');
+
+ # Print out.
+ print "ok\n";
+
+ # Output:
+ # ok
+
+=head1 EXAMPLE2
+
+=for comment filename=check_array_css_color_fail.pl
+
+ use strict;
+ use warnings;
+
+ use Error::Pure;
+ use Mo::utils::CSS qw(check_array_css_color);
+
+ $Error::Pure::TYPE = 'Error';
+
+ my $self = {
+         'key' => ['xxx'],
+ };
+ check_array_css_color($self, 'key');
+
+ # Print out.
+ print "ok\n";
+
+ # Output like:
+ # #Error [...utils.pm:?] Parameter 'key' has bad color name.
+
+=head1 EXAMPLE3
+
 =for comment filename=check_css_class_ok.pl
 
  use strict;
@@ -299,7 +401,7 @@ Returns undef.
  # Output:
  # ok
 
-=head1 EXAMPLE2
+=head1 EXAMPLE4
 
 =for comment filename=check_css_class_fail.pl
 
@@ -322,7 +424,7 @@ Returns undef.
  # Output like:
  # #Error [...utils.pm:?] Parameter 'key' has bad CSS class name (number of begin).
 
-=head1 EXAMPLE3
+=head1 EXAMPLE5
 
 =for comment filename=check_css_color_ok.pl
 
@@ -342,7 +444,7 @@ Returns undef.
  # Output:
  # ok
 
-=head1 EXAMPLE4
+=head1 EXAMPLE6
 
 =for comment filename=check_css_color_fail.pl
 
@@ -365,7 +467,7 @@ Returns undef.
  # Output like:
  # #Error [...utils.pm:?] Parameter 'key' has bad color name.
 
-=head1 EXAMPLE5
+=head1 EXAMPLE7
 
 =for comment filename=check_css_unit_ok.pl
 
@@ -385,7 +487,7 @@ Returns undef.
  # Output:
  # ok
 
-=head1 EXAMPLE6
+=head1 EXAMPLE8
 
 =for comment filename=check_css_unit_fail.pl
 
@@ -414,6 +516,7 @@ L<Error::Pure>,
 L<Exporter>,
 L<Graphics::ColorNames::CSS>,
 L<List::Util>,
+L<Mo::utils>,
 L<Readonly>.
 
 =head1 SEE ALSO
@@ -456,6 +559,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
